@@ -1,5 +1,3 @@
-
-
 import torch
 import pandas as pd
 from transformers import (
@@ -362,8 +360,9 @@ class Summarization:
             weight_decay=weight_decay,
         )
 
-        logger = DAGsHubLogger(metrics_path='reports/training_metrics.csv',
-                               should_log_hparams=False)
+        logger = DAGsHubLogger(
+            metrics_path="reports/training_metrics.csv", should_log_hparams=False
+        )
 
         early_stop_callback = (
             [
@@ -391,7 +390,7 @@ class Summarization:
 
         mlflow.pytorch.autolog(log_models=False)
 
-        with mlflow.start_run() as run:
+        with mlflow.start_run() as run:  # noqa: F841
             trainer.fit(self.T5Model, self.data_module)
 
     def load_model(
