@@ -3,6 +3,8 @@ import os
 import subprocess
 import sys
 
+import yaml
+
 arg_parser = argparse.ArgumentParser(
     description="T5 Summarisation Using Pytorch Lightning", prog="t5s"
 )
@@ -15,9 +17,41 @@ parser_req = command_subparser.add_parser(
     "requirements", help="Install Python Dependencies."
 )
 
+parser_start = command_subparser.add_parser("start", help="Define parameters")
+parser_start.add_argument(
+    "-d",
+    "--dataset",
+    default="cnn_dailymail",
+    help="Enter the name of the dataset to be used",
+)
+
+parser_start.add_argument("--split", default=0.001, help="Enter the split required")
+
+parser_start.add_argument(
+    "-n", "--name", default="summarsiation", help="Enter the name of the model"
+)
+parser_start.add_argument(
+    "-mt", "--model_type", default="t5", help="Enter the model type"
+)
+parser_start.add_argument(
+    "-m",
+    "--model_name",
+    default="t5-base",
+    help="Enter the model to be used eg t5-base",
+)
+parser_start.add_argument(
+    "-e", "--epochs", default=5, help="Enter the number of epochs"
+)
+parser_start.add_argument(
+    "-lr", "--learning-rate", default=0.0001, help="Enter the number of epochs"
+)
+parser_start.add_argument(
+    "-b", "--batch-size", default=2, help="Enter the number of batches"
+)
+
 parser_dirs = command_subparser.add_parser(
     "dirs",
-    help="Create directories that are ignored by git but required for " "the project",
+    help="Create directories that are ignored by git but required for the project",
 )
 
 parser_push = command_subparser.add_parser(
@@ -75,10 +109,9 @@ class Run(object):
             retval = os.getcwd()
             print(retval)
             return list_files.returncode
+        elif arguments["command"] == "start":
+            start(arguments=arguments)
         elif arguments["command"] in cmd:
-            os.chdir("./summarization/")
-            retval = os.getcwd()
-            print(retval)
             list_files = subprocess.run(["make", arguments["command"]])
             return list_files.returncode
         else:
@@ -86,6 +119,29 @@ class Run(object):
             raise Exception
 
 
+def start(arguments):
+    data_params = {"data": arguments["dataset"], "split": arguments["split"]}
+    model_params = {
+        "name": arguments["name"],
+        "model_type": arguments["model_type"],
+        "model_name": arguments["model_name"],
+        "epochs": arguments["epochs"],
+        "learning_rate": arguments["learning_rate"],
+        "batch_size": arguments["batch_size"],
+    }
+    with open("data_params.yml", "w") as f:
+        yaml.dump(data_params, f)
+    with open("model_params.yml") as f:
+        newdct = yaml.safe_load(f)
+    newdct.update(model_params)
+    with open("model_params.yml", "w") as f:
+        yaml.dump(newdct, f)
+    dicts = {}
+    dicts.update(newdct)
+    dicts.update(data_params)
+    print("Final parameters for the run are: {}".format(dicts))
+
+
 def parse_args(args):
     arguments = vars(arg_parser.parse_args(args=args or ["--help"]))
     return arguments
